/**
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 * 
 * Contact Information:
 * beck et al. projects GmbH
 * Theresienhoehe 13
 * 80336 Munich
 * Phone: +49-89-5442530
 * mailto: info@bea.de
 */
package de.bsvrz.ars.export;

import java.util.Collection;
import java.util.Iterator;

import de.bsvrz.ars.export.exceptions.InvalidObjectException;
import de.bsvrz.dav.daf.main.DataDescription;
import de.bsvrz.dav.daf.main.config.Aspect;
import de.bsvrz.dav.daf.main.config.AttributeGroup;
import de.bsvrz.dav.daf.main.config.SystemObject;

/**
 * Jede Instanz dieser Klasse repräsentiert genau eine Datenspezifikation (so, wie sie im Export
 * benötigt wird) plus Name.
 * 
 * @author beck et al. projects GmbH
 * @author Phil Schrettenbrunner
 * @version $Revision: 1.1 $ / $Date: 2008/01/22 16:39:42 $ / ($Author: yvonnes $)
 */
public class Dataspecification {
    private String name;
    private DataDescription dataDesc;
    private Collection<SystemObject> systemObjects;


    /**
     * Datenspezifikatoin: Datenidentifikation (Atg, Asp, SimVar), plus optionaler Name, plus Liste
     * von Objekten
     * 
     * @param systemObjects System-Objekte.
     * @param dataDescription DaV-Datenbeschreibung.
     * @param name Name.
     * @throws NullPointerException NullPointerException.
     * @throws InvalidObjectException InvalidObjectException.
     */
    @SuppressWarnings("unchecked")
    public Dataspecification(Collection systemObjects, DataDescription dataDescription, String name) throws NullPointerException,
            InvalidObjectException {
        // systemObject darf nicht null sein
        if (systemObjects == null) {
            throw new NullPointerException("systemObject");
        } else {
            this.systemObjects = systemObjects;
        }

        // und auch nicht leer sein
        if (systemObjects.size() <= 0) {
            throw new InvalidObjectException("Keine SystemObjekte in der Datenspezifikation '" + name + "'");
        } else {
            this.systemObjects = systemObjects;
        }

        // Die Datenbeschreibung des ersten Objekts legt fest, wie alle sein
        // müssen
        this.dataDesc = dataDescription;
        if (name.length() <= 0) {
            StringBuffer sb;
            if (systemObjects.size() > 0) {
                // Mame aus Objekten bauen, dabei auf gültige DatenBeschreibung
                // achten
                sb = new StringBuffer(24 * systemObjects.size());
                sb.append("[");
                for (Iterator i = systemObjects.iterator(); i.hasNext();) {
                    SystemObject so = (SystemObject) i.next();
                    sb.append(so.getNameOrPidOrId());
                    sb.append(", ");
                }
                sb.delete(sb.length() - 2, sb.length()); // löscht letztes ", "
                sb.append("]");
            } else {
                throw new NullPointerException("No SystemObjects");
            }
            this.name = sb.toString();
        } else {
            this.name = name;
        }
    }


    /**
     * Liefert die Liste der Objekte zurück
     * 
     * @return Liste der Objekte
     */
    public Collection<SystemObject> getSystemObjects() {
        return systemObjects;
    }


    /**
     * Liefert den Namen dieser Datenspezifikation
     * 
     * @return Name dieser Datenspezifikation
     */
    public String getName() {
        return name;
    }


    /**
     * Liefert den Askept dieser Datenspezifikation zurück
     * 
     * @return der Askept dieser Datenspezifikation
     */
    public Aspect getAsp() {
        return dataDesc.getAspect();
    }


    /**
     * Liefert die Attributgruppe dieser Datenspezifikation zurück
     * 
     * @return Attributgruppe dieser Datenspezifikation
     */
    public AttributeGroup getAtg() {
        return dataDesc.getAttributeGroup();
    }


    /**
     * Liefert die Simulationsvariante dieser Datenspezifikation zurück
     * 
     * @return Simulationsvariante dieser Datenspezifikation
     */
    public short getSimVar() {
        return dataDesc.getSimulationVariant();
    }


    /**
     * Liefert die Daten-Beschreibung dieser Datenspezifikation zurück
     * 
     * @return Daten-Beschreibung dieser Datenspezifikation
     */
    public DataDescription getDataDescription() {
        return dataDesc;
    }


    /**
     * Liefert den Namen dieser Datenspezifikation
     * 
     * @return Name dieser Datenspezifikation
     */
    public String toString() {
        return name;
    }
}
