/**
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 * 
 * Contact Information:
 * beck et al. projects GmbH
 * Theresienhoehe 13
 * 80336 Munich
 * Phone: +49-89-5442530
 * mailto: info@bea.de
 */
package de.bsvrz.ars.export;

import de.bsvrz.ars.export.interfaces.ProgressListener;
import de.bsvrz.ars.export.prot.ProtocollerAdapter;

/**
 * Diese Klasse führt den Export durch.
 * 
 * Dazu erhält sie ein Exportprofil (@link de.bsvrz.ars.export.ExportProfile), das alle Daten enthält, die
 * für den Export nötig sind.
 * 
 * Es kann ein ProgressListener (@link de.bsvrz.ars.export.interfaces.ProgressListener) registriert werden,
 * der über den Fortschritt des Exports informiert wird.
 * 
 * 
 * @author beck et al. projects GmbH
 * @author Phil Schrettenbrunner
 * @version $Revision: 1.1 $ / $Date: 2008/01/22 16:39:42 $ / ($Author: yvonnes $)
 */
public class ExportManager {

    private ProtocollerAdapter pa;
    private ExportProfile exportProfile;
    private ProgressListener progressListener;


    /**
     * Erstellt einen ExportManager (mit ExportProfile), der sich um das Durchführen des Exportes
     * kümmert
     * 
     * @param exportProfile ExportProfil mit den Daten, für den Export
     */
    public ExportManager(ExportProfile exportProfile) {
        this.exportProfile = exportProfile;
        this.progressListener = null;
    }


    /**
     * Erstellt einen ExportManager (mit ExportProfile), der sich um das Durchführen des Exportes
     * kümmert
     * 
     * @param exportProfile ExportProfil mit den Daten, für den Export
     * @param progressListener Listener, der über den Fotschritt informiert wird
     */
    public ExportManager(ExportProfile exportProfile, ProgressListener progressListener) {
        this.exportProfile = exportProfile;
        this.progressListener = progressListener;
    }


    /**
     * Setzt/Ändern den Fortschritts Listener
     * 
     * @param progressListener ProgressListener.
     */
    public void setProgressListener(ProgressListener progressListener) {
        this.progressListener = progressListener;
    }


    /**
     * Startet den Arbeiterthread und das Progressfenster
     */
    public void beginExport() {
        if (progressListener != null)
            pa = new ProtocollerAdapter(exportProfile, progressListener);
        else
            pa = new ProtocollerAdapter(exportProfile);
        if (pa.isReady()) {
            if (progressListener != null) {
                javax.swing.SwingUtilities.invokeLater(new Runnable() {
                    public void run() {
                        progressListener.init(pa);
                    }
                });
            }
            pa.start();
        } else {
            System.out.println("PROT ADAPTER NOT READY!!!"); // XXX gui
        }
    }
    
    
    /**
     * Wartet, bis der Thread fertig ist. 
     */
    public void waitUntilDone() {
        try {
            if (pa != null)
                pa.join();
        } catch (InterruptedException e) {// ignorieren
        }
    }

}
